[![Build Status](https://travis-ci.org/SpikeInterface/spikewidgets.svg?branch=master)](https://travis-ci.org/SpikeInterface/spikewidgets) [![PyPI version](https://badge.fury.io/py/spikewidgets.svg)](https://badge.fury.io/py/spikewidgets)

# SpikeWidgets

SpikeWidgets is a package of the SpikeInterface project that was designed for visualization of various aspects of the spike sorting pipeline. The widgets include: raster plots, autocorrelograms, crosscorrelograms, isi distributions, and more.

## Getting Started

To get started with SpikeWidgets, you can install it with pip:

```shell
pip install spikewidgets
```

You can also get SpikeWidgets through the [spikeinterface](https://github.com/SpikeInterface/spikeinterface) package:

```shell
pip install spikeinterface
```

You can also install SpikeWidgets locally by cloning the repo into your code base. If you install SpikeWidgets locally, you need to run the setup.py file.

```shell
git clone https://github.com/SpikeInterface/spikewidgets.git
cd spikewidgets
python setup.py install
```

## Examples

For more information about how to use SpikeWidgets, please checkout these [examples](https://github.com/SpikeInterface/spikeinterface/tree/master/examples/modules/widgets).

## Documentation

All documentation for SpikeInterface can be found here: https://spikeinterface.readthedocs.io/en/latest/.

### Authors

[Alessio Paolo Buccino](https://www.mn.uio.no/ifi/english/people/aca/alessiob/) - Center for Inegrative Neurolasticity (CINPLA), Department of Biosciences, Physics, and Informatics, University of Oslo, Oslo, Norway

[Cole Hurwitz](https://www.inf.ed.ac.uk/people/students/Cole_Hurwitz.html) - The Institute for Adaptive and Neural Computation (ANC), University of Edinburgh, Edinburgh, Scotland

[Jeremy Magland](https://www.simonsfoundation.org/team/jeremy-magland/) - Center for Computational Biology (CCB), Flatiron Institute, New York, United States

[Matthias Hennig](http://homepages.inf.ed.ac.uk/mhennig/) - The Institute for Adaptive and Neural Computation (ANC), University of Edinburgh, Edinburgh, Scotland

[Samuel Garcia](https://github.com/samuelgarcia) - Centre de Recherche en Neuroscience de Lyon (CRNL), Lyon, France

<br/>
<br/>
For any correspondence, contact Alessio Buccino at alessiop.buccino@gmail.com
